

set -ex



test -f ${PREFIX}/bin/x86_64-conda_cos7-linux-gnu-gfortran
test -f ${PREFIX}/bin/x86_64-conda-linux-gnu-gfortran
find $PREFIX/lib -iname omp_lib.mod | grep '.'
find $PREFIX/lib -iname omp_lib.h | grep '.'
pushd tests/fortomp || exit 1
sh test_fort.sh  || true
popd
exit 0
